function outputdata = LSM()
	tic
	clc
	close all
	clear all
    clf
    warning off
    
	fprintf('Starting Particle Swarm Optimisation using LSM program..\n');
    global modelInfo
    global lsmData
	global doeData
	global lsmOutputData
	
    % LSM settings.
    npoly=1;		% Order of polynomial base function.
	lsmData.npoly=npoly;

    % optimise analytical (0) or metamodel-based (1) response surface
    modelInfo.using_metamodel=0;
    
    % read in DoE and design space data
    % create training DoE points using analytical function
    doeData=readDoEData();
    
    % BUT do optimisation with data from least squares metamodel
    modelInfo.using_metamodel=1;

    % intialise DoE data
    x=doeData.x; n=doeData.n; ndv=doeData.ndv; rang=doeData.rang; f=doeData.f;
    bounds=doeData.bounds;

    outputdata = [];	
    
    % initalise plan points where LSM response to be calculated
	lsmOutputData=readOutputData();
    xa=lsmOutputData.xa; na=lsmOutputData.na;
    
	% Evaluate plan points xa using LSM with optimised theta value
	fprintf('Creating standard least squares approximation\n');
    
    % calculate LS coefficients
    c=lscoefficients(n,x,npoly,ndv,f);
    lsmData.c=c;
    
    ya=leastsquares(c,na,xa,npoly,ndv);
	save function_approx_optimum.txt ya
	fprintf('Finished creating approximation..\n');
         
    %Code for visualising predicted surface
    xz = [];
    for i = 1:41
        for j = 1:41
            xz(j,i) = ya(((i-1)*41)+j);
        end
    end

    close all
        
    [xcd ycd] = meshgrid(0:1/40:1,0:1/40:1);
        
    %Display the predicted surface
    string1 = 'Quartic Least Squares Hump Camel Back Function with OLH sampling n= ';
    titlestring = strcat(string1,num2str(n))

    figure(1)
    surf(xcd,ycd,xz)

    xlabel('x1')
    ylabel('x2')
    zlabel('f(x1,x2)')
    title(titlestring)
    hold on
        	
	% plot LS response at DoE points on the LS response surface
	% ydoe =leastsquares(c,n,x,npoly,ndv);
    % scatter3(x(:,1),x(:,2),ydoe,15,'red','fill');
    scatter3(x(:,1),x(:,2),f,15,'red','fill');    
       
    PS=1;   % run Particle Swarm to find global minimum of response function
    if PS==1
        psoOptions = get_psoOptions;
        
        % update PS parameters to comply with those already set for design space 
        % note have to be careful with design variable boundaries as these
        % are currently assumed to be the same in each variable - would
        % need to update PS code to allow this (quite straightforward)
        psoOptions.SParams.lb = bounds(1,1);
        psoOptions.Sparams.ub = bounds(1,2);
        psoOptions.Vars.Dim = ndv;
        
        [fxmin, xmin, Swarm, history] = pso(psoOptions);
        x1opt = xmin(1,1);
        x2opt = xmin(1,2);
        Optval = fxmin;
        fprintf('Optimum design variables: x1opt=%f, x2opt=%f\n',x1opt,x2opt);
        fprintf('Optval=%f\n',fxmin);
        fprintf('True prediction at optimum point=%f\n',analytical_response([x1opt x2opt]))
        scatter3(x1opt,x2opt,Optval,50,'yellow','fill');
    end

	fprintf('Finished PSO LSM program..\n');
	toc
end