function [xout,fout]=golden(a,b,eps,maxiter,x,xv,n,nxv,npoly,ndv,f,fxv,sens,rang,s,vmethod,dWmin,nExcessPts)
      fprintf('Starting golden search algorithm..\n');
      fprintf('\n')
      fprintf('--------------GOLDEN SEARCH OPTIMISATION--------------\n')
      fprintf('\n')
      fprintf('Objective: minimise f(x)\n');
      fprintf('Bounds: %8.5f < x < %8.5f\n', a,b);
      fprintf('Residual tolerance: %8.5f\n',eps);
      fprintf('Max iterations: %d\n',maxiter);
      fprintf('\n')

      c=(-1+sqrt(5))/2;
	x1=c*a+(1-c)*b;
      x2=c*b+(1-c)*a;
      
      fprintf('Evaluating start points..\n');
      fx1=validation(x1,x,xv,n,nxv,npoly,ndv,f,fxv,sens,rang,s,vmethod,dWmin,nExcessPts);
      fx2=validation(x2,x,xv,n,nxv,npoly,ndv,f,fxv,sens,rang,s,vmethod,dWmin,nExcessPts);
      hold on
      fprintf('Starting iterations..\n');
      fprintf('\n')
      fprintf('------------------------------------------------------\n')
      fprintf('  #     Residual         x                f(x)        \n');
      fprintf('------------------------------------------------------\n')
      for i=1:maxiter
            if fx1<fx2
                  b=x2;
                  x2=x1;
                  fx2=fx1;
                  x1=c*a+(1-c)*b;
                  fx1=validation(x1,x,xv,n,nxv,npoly,ndv,f,fxv,sens,rang,s,vmethod,dWmin,nExcessPts);
                  fprintf('%3d     %10.5e     %10.5e     %10.5e\n',i,b-a,x1,fx1)
                  hold on
                  plot(x1,fx1,'*')
                  hold off
                  drawnow
            else
                  a=x1;
                  x1=x2;
                  fx1=fx2;
                  x2=(1-c)*a+c*b;
                  fx2=validation(x2,x,xv,n,nxv,npoly,ndv,f,fxv,sens,rang,s,vmethod,dWmin,nExcessPts);
                  fprintf('%3d     %10.5e     %10.5e     %10.5e\n',i,b-a,x2,fx2)
                  hold on
                  plot(x2,fx2,'*')
                  hold off
                  drawnow
            end
            if (abs(b-a) < eps)
                  fprintf('\n')
                  fprintf('Converged after %d iterations!\n', i);
                  if fx1<fx2
                        xout=x1;
                        fout=fx1;
                  else
                        xout=x2;
                        fout=fx2;
                  end
                  fprintf('\n')
                  fprintf('Function minimum f = %9.5f ', fout);
                  fprintf('at x = %9.5f \n', xout);
                  fprintf('------------------------------------------------------\n')
                  fprintf('\n')
                  return;
            end
      end
      fprintf('\n')
      fprintf('Failed to converge after %d iterations, \nusing conventional least squares regression\n', i);
      fprintf('------------------------------------------------------\n')
      fprintf('\n')
      xout=0.0;
      fout=NaN;
      fprintf('\n')
      fprintf('Finished golden search algorithm..\n');
end