function mlsmValidationData=readMLSMValidationData()
	
    global modelInfo
    global mlsmData
    global doeData
    
    fprintf('Reading MLSM Valdation Data..\n');
	vmethod=mlsmData.vmethod;		% (1) - Validation matrix, (2) - Leave One Out, (2) - K-fold (3).
	if vmethod==1
		% Validation Matrix on OLH sample
		xv = load ('-ascii', '../OLH/OLH_UNI_2x20.txt');
	else 
		xv=[];
        fxv=[];
        nfv = 0;
	end
	    
    % Calculating number of plan points for xv
	nxv=size(xv,1);
	nDVARS = size(xv,2);
    
    % verify that the specified number of design variables in validation
    % matrix is consistent with DoE points
	ndv=doeData.ndv;
    if (ndv ~= nDVARS)
       fprintf('Number of design variables data mismatch\n');
       quit cancel;
    end

	% Scaling plan point values for x,xa,xv if using uni-plan run-matrix
    uniplan = doeData.uniplan;
	bounds=doeData.bounds;
	rang=doeData.rang;
	if uniplan==1  % scale DoE points within the specified limits
		for i=1:ndv
			if vmethod==1
				xv(:,i)=rang(1,i)*xv(:,i)+bounds(i,1);
			end
		end
    end
		
	% Obtain response values at DoE validation points
	if vmethod==1
	   if modelInfo.using_metamodel==0    % calculate response from analytical functions
		   fxv=analytical_response(xv);
	   else
	       % read in response values at DoE validation points
           fxv = load ('-ascii',  'DoEvalidationresponse.txt');
	       % verify that the specified DoE validation size is consistent with those read in
           nfvPOINTS=size(fxv,1);
           if (nfvPOINTS ~= nxv)
              fprintf('DoE validation response data mismatch in readDoEData\n');
              quit cancel;
           end
       end
    end
	   
    % assemble MLSM validation data into global structure so data can be passed into other functions
	mlsmValidationData.xv=xv;
	mlsmValidationData.nxv=nxv;
    mlsmValidationData.fxv=fxv;

    fprintf('Finished reading MLSM Validation Data..\n');
end
