function RMSE=validation(theta,x,xv,n,nxv,npoly,ndv,f,fxv,sens,rang,s,vmethod,dWmin,nExcessPts)
	% Validation matrix
	if vmethod==1
		% Creating approximation
		ya=movingls(theta,n,nxv,x,xv,npoly,ndv,f,sens,rang,s,dWmin,nExcessPts);
		% Error squared [1 x nxv]
		err=(ya-fxv(:,1)).^2;
		% Root mean squared error
		RMSE=sqrt(sum(err)/nxv);
		% Error sum of squares
		SSE=sqrt(sum(err));
		% Total sum of squares
		SSTO=sqrt(sum((fxv(:,1)-mean(fxv(:,1))).^2));
		% Coefficient of determination
		R2=1-SSE/SSTO;
	
	% Leave One out
	elseif vmethod==2
		% Leave one point out of the model build at a time
		err=0;
		for p=1:n
			xp=x(p,:);
			fp=f(p,1);
			xr=[x(1:p-1,:)
			    x(p+1:end,:)];
			fr=[f(1:p-1,:)
			    f(p+1:end,:)];
			% Create approximation at the left out point
			yp=movingls(theta,n-1,1,xr,xp,npoly,ndv,fr,sens,rang,s,dWmin,nExcessPts);
			% Errors squared [1 x n]
			err=err+(yp-fp)^2;
		end
		% Root mean squared error
		RMSE=sqrt(err/n);
		
	% K-fold
	elseif vmethod==3
		err=0;
		k=13;
		k_iters=1000;
		tol=0.05;
		for i=1:k_iters
			% Select k random points out of n possible
			pts=randi(n,1,k);
			keep=1;
			while keep
				keep=0;
				% Calculate distance matrix for the k points
				Rpts=rmatrix(x(pts,:),x(pts,:),rang);
				for r=1:k
					for c=1:r-1
						if (Rpts(r,c) < tol)
							pts(c)=randi(n,1,1);
							keep=1;
						end
					end
				end
			end					
			
			% Leave the k points out of the model build
			xr=x;
			fr=f;
			for p=1:k
				xp(p,:)=x(pts(p),:);
				fp(p,:)=f(pts(p),1);
				xr=[xr(1:pts(p)-1,:)
				    xr(pts(p)+1:end,:)];
				fr=[fr(1:pts(p)-1,:)
				    fr(pts(p)+1:end,:)];
				% Update indices in pts after leaving point p out.
				for np=p+1:k
					if pts(np) > pts(p)
						pts(np)=pts(np)-1;
					end
				end
			end
			% Validate at the k left out points
			yp=movingls(theta,n-k,k,xr,xp,npoly,ndv,fr,sens,rang,s,dWmin,nExcessPts);
			% Mean error squared over k points
			err=err+sum((yp-fp).^2)/k;
		end
		% Root mean squared error
		RMSE=sqrt(sum(err)/k_iters);
	end
end