function W=wmatrix(x,xa,theta,rang,dWmin,nExcessPts,dim,n)
	% Create normalised distance matrix
	R=rmatrix(x,xa,rang);
	
	RminG=0;
	Epsilon=0.001;
	Rsort=zeros(size(R));
	for j=1:size(R,2)
		% Sorting R-values for each evaluation point j
		Rsort(:,j)=sort(R(:,j));
		% Calculate minimum radius of influence for dim points.
		RminL=Rsort(dim,j);
		if ( RminL<RminG || j==1 )
			RminG=RminL;
		end
	end
	
	ThetaMax=-log(Epsilon)/RminG^2;
	
	% Scaling theta to the range 0-10 where 0 corresponds to traditional LS and 10 is a very close MLSM fit
	thsc=0;	% Set to zero to supress the scaling
	if thsc==0
		% No scaling:
		thetaUnsc=theta;
	elseif thsc==1
		% Linear scaling:
		thetaUnsc=theta*ThetaMax/10.0;
	elseif thsc==2
		% Quadratic scaling:
		thetaUnsc=(theta^2)*ThetaMax/100.0;
	elseif thsc==3
		% Cubic scaling:
		thetaUnsc=(theta^3)*ThetaMax/1000.0;
	end
	
	% Make sure weights are not smaller than dWmin
	W=zeros(size(R));
	for j=1:size(R,2)
		% Calculating smalles radius of influence including <dim+nExcessPts> points
		Rmin=Rsort(dim+nExcessPts,j);
		% Making sure that theta will not yeild smaller weight than dWmin for current point
		thetaUpd=min(thetaUnsc,-log(dWmin)/Rmin^2);
		% Calculate weights based on theta
		W(:,j)=exp((-thetaUpd*R(:,j).^2));        
    end
end