function outputdata = RBF()
	tic
	clc
	close all
	clear all
    clf
    warning off
    
	fprintf('Starting Particle Swarm Optimisation using RBF program..\n');
    global modelInfo
    global rbfData
	global doeData
	global rbfOutputData
	
    % RBF settings.
    rbfmodel=2;		% 1 = gaussian; 2=multi-quadratic; 3=inverse multi-quadratic
	beta=2.0;
    rbfData.rbfmodel=rbfmodel; rbfData.beta=beta;
    
    % optimise analytical (0) or metamodel-based (1) response surface
    modelInfo.using_metamodel=1;
    
    % read in DoE and design space data
    % first calculate data at DoE points using analytical solutions
    modelInfo.using_metamodel=0;    
    doeData=readDoEData();

    % then optimise using rbf response surfaces
    modelInfo.using_metamodel=1;    
    
    % intialise DoE data
    x=doeData.x; n=doeData.n; ndv=doeData.ndv; rang=doeData.rang; f=doeData.f;
    bounds=doeData.bounds;

    outputdata = [];	
    
    % initalise plan points where RBF response to be calculated
	rbfOutputData=readOutputData();
    xa=rbfOutputData.xa; na=rbfOutputData.na;
    
	fprintf('Creating RBF approximation\n');
    
    % calculate RBF weights lambda
    lambda=rbfweights(n,x,ndv,f,rbfmodel,beta);
    rbfData.lambda=lambda;
    
	% Evaluate RBF approximation at plan points xa using specified RBFs  
    ya=rbf(n,x,ndv,xa,na,lambda,rbfmodel,beta);
    
	save function_approx_optimum.txt ya
	fprintf('Finished creating approximation..\n');
         
    %Code for visualising predicted surface
    xz = [];
    for i = 1:41
        for j = 1:41
            xz(j,i) = ya(((i-1)*41)+j);
        end
    end

    close all
        
    [xcd ycd] = meshgrid(0:1/40:1,0:1/40:1);
        
    %Display the predicted surface
    string1 = 'inverse multiquadratic RBF with beta=';
    string2 = ' for Camel Function with OLH sampling n= ';
    titlestring = strcat(string1,num2str(beta),string2, num2str(n));

    figure(1)
    surf(xcd,ycd,xz)

    xlabel('x1')
    ylabel('x2')
    zlabel('f(x1,x2)')
    title(titlestring)
    hold on
        	
	% plot LS response at DoE points on the LS response surface
    scatter3(x(:,1),x(:,2),f,15,'red','fill');    
       
    PS=1;   % run Particle Swarm to find global minimum of response function
    if PS==1
        psoOptions = get_psoOptions;
        
        % update PS parameters to comply with those already set for design space 
        % note have to be careful with design variable boundaries as these
        % are currently assumed to be the same in each variable - would
        % need to update PS code to allow this (quite straightforward)
        psoOptions.SParams.lb = bounds(1,1);
        psoOptions.Sparams.ub = bounds(1,2);
        psoOptions.Vars.Dim = ndv;
        
        [fxmin, xmin, Swarm, history] = pso(psoOptions);
        x1opt = xmin(1,1);
        x2opt = xmin(1,2);
        Optval = fxmin;
        fprintf('Optimum design variables: x1opt=%f, x2opt=%f\n',x1opt,x2opt);
        fprintf('Optval=%f\n',fxmin);
        fprintf('True prediction at optimum point=%f\n',analytical_response([x1opt x2opt]))
        scatter3(x1opt,x2opt,Optval,50,'yellow','fill');
    end

	fprintf('Finished PSO LSM program..\n');
	toc
end