function doeData=readDoEData()

    global modelInfo

    addpath('..\Sampling Plans');

	fprintf('Reading DoE and design space data..\n');
		
    nPOINTS = 50;   % number of DoE points
    nDVARS = 2;     % number of design variables
    ndv = nDVARS;
    
    % design variable limits
    bounds=[0 1
		    0 1];
	
    OLH=0;
    if OLH==1
        % read in OLH values pre-calculated using permGA
        x = load ('-ascii',  '../OLH/OLH_UNI_2x400.txt');
    else
        % Creating sampling plan
        x=bestlh(nPOINTS,ndv,20,20);
    end
        
    % Calculating number of DoE points for matrix x
    n=size(x,1);
	
	% Calculating number of dvs
	ndv=size(x,2);
	
    % verify that the specified DoE sizes are consistent with those read in
    if ((n ~= nPOINTS) || (ndv ~= nDVARS))
       fprintf('DoE data mismatch\n');
       quit cancel;
    end

	% Calculating range of each design variable
	for i=1:ndv
		rang(1,i)=bounds(i,2)-bounds(i,1);
    end
    
	% Scaling plan point values for x,xa,xv if using uni-plan run-matrix
    uniplan = 1; 
	if uniplan==1
        % scale DoE points within the specified limits
		for i=1:ndv
			x(:,i)=rang(1,i)*x(:,i)+bounds(i,1);
		end
    end
 	
	% Obtain response values at DoE points
	if modelInfo.using_metamodel==0    % calculate response from analytical functions
		f=analytical_response(x);
	else
	    % read in response values at DoE points
        f = load ('-ascii',  'DoEresponse.txt');
		% verify that the specified DoE size is consistent with those read in
        nfPOINTS=size(f,1);
        if (nfPOINTS ~= n)
           fprintf('DoE response data mismatch in readDoEData\n');
           quit cancel;
        end
    end

	% assemble DoE data into global structure so data can be passed into other functions
	doeData.x=x;
	doeData.bounds=bounds;
	doeData.n=n;
	doeData.ndv=ndv;
	doeData.rang=rang;
	doeData.uniplan=uniplan;
	doeData.f=f;
	
    fprintf('Finished reading DoE data..\n');
		
end