% Kriging Six Hump Camel example with global minimum of function
%
% Copyright 2007 A I J Forrester
%
% This program is free software: you can redistribute it and/or modify  it
% under the terms of the GNU Lesser General Public License as published by
% the Free Software Foundation, either version 3 of the License, or any
% later version.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
% General Public License for more details.
% 
% You should have received a copy of the GNU General Public License and GNU
% Lesser General Public License along with this program. If not, see
% <http://www.gnu.org/licenses/>.
clc
clear all
close all
clf

addpath('../Sampling Plans');
addpath('../Example Problems');
addpath('../Exploring and Exploiting a Surrogate');
addpath('../Constructing a Surrogate');

kriging = 1;
if kriging

   global ModelInfo
   % Number of variables
   k=2;
   % Number of sample points
   n=50;

   % Creating sampling plan
   ModelInfo.X=bestlh(n,k,50,20);

   % Calculate observed data
   for i=1:n
       ModelInfo.y(i,1)=sixhumpcamel(ModelInfo.X(i,:));
   end

   % Set upper and lower bounds for search of log theta
   UpperTheta=ones(1,k).*2;
   LowerTheta=ones(1,k).*-3;

   % Run GA search of likelihood
   [ModelInfo.Theta,MinNegLnLikelihood]=...
       ga(@likelihood,k,[],[],[],[],LowerTheta,UpperTheta);

   % Put Cholesky factorization of Psi, into ModelInfo
   [NegLnLike,ModelInfo.Psi,ModelInfo.U]=likelihood(ModelInfo.Theta);

   plotting_results = 1;
   if plotting_results
      theta1 = ModelInfo.Theta(1,1)
      theta2 = ModelInfo.Theta(1,2)
      fprintf('Optimum values: NeglnLike=%f theta1=%f theta2=%f\n',...
         NegLnLike,10^theta1,10^theta2);

      % plot camel function out now
      Xplot=0:1/40:1;
      for i=1:41
         for j=1:41
            sixhumpPred(j,i)=pred([Xplot(i),Xplot(j)]);
         end
      end

      [Xcd,Ycd] = meshgrid(Xplot,Xplot);
      p1=surf(Xcd, Ycd, sixhumpPred);
      title(strcat('Kriging Prediction of Hump Camel Back function n=',num2str(n))), xlabel('x1'),...
          ylabel('x2'),zlabel('f');
      set(p1,'facealpha',0.2)
      hold on
      for i=1:n
          SamplePred(i)=pred([ModelInfo.X(i,1),ModelInfo.X(i,2)]);
      end
      scatter3(ModelInfo.X(:,1),ModelInfo.X(:,2),SamplePred,15,'red','fill');
   end
   
   % now find global minimum of hump camel back function
   % design variables 0 <= x1, x2 <= 1
   UpperBound=ones(1,k);
   LowerBound=ones(1,k)*0;
   
   % Run GA search of hump camel back function
    [ModelInfo.Optvars,Optval]=...
       ga(@pred,k,[],[],[],[],LowerBound,UpperBound);
  
    x1opt = ModelInfo.Optvars(1);
    x2opt = ModelInfo.Optvars(2);
    fprintf('Opt design variables: x1opt=%f, x2opt=%f\n',x1opt,x2opt);
    fprintf('Optval=%f\n',Optval);
    fprintf('True prediction at optimum point=%f\n',sixhumpcamel([x1opt x2opt]))
    % plot optimum value
    scatter3(x1opt,x2opt,Optval,50,'blue','fill');
    
else
    
   % plot six hump camel function out
   Xplot=0:1/40:1;
   for i=1:41
      for j=1:41
          sixhumptrue(j,i)=sixhumpcamel([Xplot(i),Xplot(j)]);
      end
   end

   [Xcd,Ycd] = meshgrid(Xplot,Xplot);
   p1=surf(Xcd, Ycd, sixhumptrue);
   title('True SixHump Camel function'), xlabel('x1'),...
       ylabel('x2'),zlabel('f');
   set(p1,'facealpha',0.2)
   colorbar;
end